@@ -1,4 +1,5 @@
 import logging
+
 logger = logging.getLogger(__name__)
 
 import attr
@@ -23,17 +24,26 @@ import time
 import twisted.internet.defer
 import twisted.internet.threads
 
-from PyQt5.QtCore import (Qt, QVariant, QModelIndex, pyqtSignal, pyqtSlot,
-                          QTimer, QObject, QCoreApplication)
+from PyQt5.QtCore import (
+    Qt,
+    QVariant,
+    QModelIndex,
+    pyqtSignal,
+    pyqtSlot,
+    QTimer,
+    QObject,
+    QCoreApplication,
+)
 from PyQt5.QtWidgets import QMessageBox
 
 # See file COPYING in this source tree
-__copyright__ = 'Copyright 2016, EPC Power Corp.'
-__license__ = 'GPLv2+'
+__copyright__ = "Copyright 2016, EPC Power Corp."
+__license__ = "GPLv2+"
 
 
 class Columns(epyqlib.abstractcolumns.AbstractColumns):
-    _members = ['name', 'type', 'address', 'size', 'bits', 'value', 'file']
+    _members = ["name", "type", "address", "size", "bits", "value", "file"]
+
 
 Columns.indexes = Columns.indexes()
 
@@ -65,30 +75,39 @@ def build_node_tree(variables, array_truncated_slot):
 
 
 class VariableNode(epyqlib.treenode.TreeNode):
-    def __init__(self, variable, name=None, address=None, bits=None,
-                 tree_parent=None, comparison_value=None):
+    def __init__(
+        self,
+        variable,
+        name=None,
+        address=None,
+        bits=None,
+        tree_parent=None,
+        comparison_value=None,
+    ):
         epyqlib.treenode.TreeNode.__init__(self, parent=tree_parent)
 
         self.variable = variable
         name = name if name is not None else variable.name
         address = address if address is not None else variable.address
         if bits is None:
-            bits = ''
+            bits = ""
 
-        filename = ''
-        if hasattr(variable, 'file'):
+        filename = ""
+        if hasattr(variable, "file"):
             filename = variable.file
 
         base_type = epyqlib.cmemoryparser.base_type(variable)
         type_name = epyqlib.cmemoryparser.type_name(variable)
 
-        self.fields = Columns(name=name,
-                              type=type_name,
-                              address='0x{:08X}'.format(address),
-                              size=base_type.bytes,
-                              bits=bits,
-                              value=None,
-                              file=filename)
+        self.fields = Columns(
+            name=name,
+            type=type_name,
+            address="0x{:08X}".format(address),
+            size=base_type.bytes,
+            bits=bits,
+            value=None,
+            file=filename,
+        )
 
         self.comparison_value = comparison_value
 
@@ -129,9 +148,7 @@ class VariableNode(epyqlib.treenode.TreeNode):
             top_ancestor = top_ancestor.tree_parent
 
         top_ancestor.traverse(
-            call_this=append_address,
-            payload=addresses,
-            internal_nodes=True
+            call_this=append_address, payload=addresses, internal_nodes=True
         )
 
         def set_partially_checked(node, _):
@@ -172,39 +189,33 @@ class VariableNode(epyqlib.treenode.TreeNode):
         qualified_name = next(names)
 
         for name in names:
-            if name.startswith('['):
+            if name.startswith("["):
                 n = int(name[1:-1])
-                qualified_name += '[{}]'.format(n)
+                qualified_name += "[{}]".format(n)
             else:
-                qualified_name += '.' + name
+                qualified_name += "." + name
 
         return qualified_name
 
     def chunk_updated(self, data):
         self.fields.value = self.variable.unpack(data)
 
-    def add_members(self, base_type, address, expand_pointer=False,
-                    sender=None):
+    def add_members(self, base_type, address, expand_pointer=False, sender=None):
         new_members = []
 
         if isinstance(base_type, epyqlib.cmemoryparser.Struct):
-            new_members.extend(
-                self.add_struct_members(base_type, address))
+            new_members.extend(self.add_struct_members(base_type, address))
 
         if isinstance(base_type, epyqlib.cmemoryparser.ArrayType):
             new_members.extend(
-                self.add_array_members(
-                    base_type, address, sender=sender))
+                self.add_array_members(base_type, address, sender=sender)
+            )
 
-        if (expand_pointer and
-                isinstance(base_type, epyqlib.cmemoryparser.PointerType)):
-            new_members.extend(
-                self.add_pointer_members(base_type, address))
+        if expand_pointer and isinstance(base_type, epyqlib.cmemoryparser.PointerType):
+            new_members.extend(self.add_pointer_members(base_type, address))
 
         if isinstance(base_type, epyqlib.cmemoryparser.Union):
-            new_members.extend(
-                self.add_union_members(base_type, address)
-            )
+            new_members.extend(self.add_union_members(base_type, address))
 
         for child in self.children:
             base_type = epyqlib.cmemoryparser.base_type(child.variable)
@@ -213,11 +224,13 @@ class VariableNode(epyqlib.treenode.TreeNode):
                 base_type = epyqlib.cmemoryparser.base_type(self.variable)
                 address = self.address()
 
-            new_members.extend(child.add_members(
-                base_type=base_type,
-                address=address,
-                # do not expand child pointers since we won't have their values
-            ))
+            new_members.extend(
+                child.add_members(
+                    base_type=base_type,
+                    address=address,
+                    # do not expand child pointers since we won't have their values
+                )
+            )
 
         return new_members
 
@@ -226,10 +239,7 @@ class VariableNode(epyqlib.treenode.TreeNode):
         for name, member in base_type.members.items():
             child_address = address + base_type.offset_of([name])
             child_node = VariableNode(
-                variable=member,
-                name=name,
-                address=child_address,
-                bits=member.bit_size
+                variable=member, name=name, address=child_address, bits=member.bit_size
             )
             self.append_child(child_node)
             new_members.append(child_node)
@@ -247,10 +257,7 @@ class VariableNode(epyqlib.treenode.TreeNode):
     def array_indexes(self):
         indexes = ()
         parent = self
-        while (
-                parent.tree_parent is not None
-                and parent.fields.name.startswith('[')
-        ):
+        while parent.tree_parent is not None and parent.fields.name.startswith("["):
             indexes += (int(parent.fields.name[1:-1]),)
             parent = parent.tree_parent
 
@@ -261,7 +268,7 @@ class VariableNode(epyqlib.treenode.TreeNode):
 
         new_members = []
         digits = len(str(base_type.dimensions[len(indexes)]))
-        format = '[{{:0{}}}]'.format(digits)
+        format = "[{{:0{}}}]".format(digits)
 
         maximum_children = 256
 
@@ -277,15 +284,15 @@ class VariableNode(epyqlib.treenode.TreeNode):
                 type=child_type,
                 address=child_address,
             )
-            child_node = VariableNode(variable=variable,
-                                      comparison_value=index)
+            child_node = VariableNode(variable=variable, comparison_value=index)
             self.append_child(child_node)
             new_members.append(child_node)
 
         if base_type.dimensions[len(indexes)] > maximum_children:
             if sender is not None:
                 sender.array_truncated(
-                    maximum_children, self.fields.name, base_type.length())
+                    maximum_children, self.fields.name, base_type.length()
+                )
 
             # TODO: add a marker showing visually that it has been truncated
 
@@ -296,9 +303,9 @@ class VariableNode(epyqlib.treenode.TreeNode):
         target_type = epyqlib.cmemoryparser.base_type(base_type.type)
         if not isinstance(target_type, epyqlib.cmemoryparser.UnspecifiedType):
             variable = epyqlib.cmemoryparser.Variable(
-                name='*{}'.format(self.fields.name),
+                name="*{}".format(self.fields.name),
                 type=base_type.type,
-                address=self.fields.value
+                address=self.fields.value,
             )
             child_node = VariableNode(variable=variable)
             self.append_child(child_node)
@@ -328,26 +335,29 @@ class VariableNode(epyqlib.treenode.TreeNode):
 
         for name in variable_path:
             if name is None:
-                raise TypeError('Unable to search by None')
+                raise TypeError("Unable to search by None")
 
-            variable, = (v for v in variable.children
-                         if name in (v.fields.name, v.comparison_value))
+            (variable,) = (
+                v
+                for v in variable.children
+                if name in (v.fields.name, v.comparison_value)
+            )
 
         return variable
 
 
 class Variables(epyqlib.treenode.TreeNode):
     # TODO: just Rx?
-    changed = pyqtSignal(epyqlib.treenode.TreeNode, int,
-                         epyqlib.treenode.TreeNode, int,
-                         list)
+    changed = pyqtSignal(
+        epyqlib.treenode.TreeNode, int, epyqlib.treenode.TreeNode, int, list
+    )
     begin_insert_rows = pyqtSignal(epyqlib.treenode.TreeNode, int, int)
     end_insert_rows = pyqtSignal()
 
     def __init__(self):
         epyqlib.treenode.TreeNode.__init__(self)
 
-        self.fields = Columns.fill('')
+        self.fields = Columns.fill("")
 
     def unique(self):
         return id(self)
@@ -363,13 +373,13 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
     binary_loaded = pyqtSignal()
 
     def __init__(
-            self,
-            nvs,
-            nv_model,
-            bus,
-            tx_id=0x1FFFFFFF,
-            rx_id=0x1FFFFFF7,
-            parent=None,
+        self,
+        nvs,
+        nv_model,
+        bus,
+        tx_id=0x1FFFFFFF,
+        rx_id=0x1FFFFFF7,
+        parent=None,
     ):
         checkbox_columns = Columns.fill(False)
         checkbox_columns.name = True
@@ -377,17 +387,17 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         root = epyqlib.variableselectionmodel.Variables()
 
         epyqlib.pyqabstractitemmodel.PyQAbstractItemModel.__init__(
-                self, root=root, checkbox_columns=checkbox_columns,
-                parent=parent)
+            self, root=root, checkbox_columns=checkbox_columns, parent=parent
+        )
 
         self.headers = Columns(
-            name='Name',
-            type='Type',
-            address='Address',
-            size='Size',
-            bits='Bits',
-            value='Value',
-            file='File'
+            name="Name",
+            type="Type",
+            address="Address",
+            size="Size",
+            bits="Bits",
+            value="Value",
+            file="File",
         )
 
         self.nvs = nvs
@@ -403,17 +413,17 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         self.pull_log_progress = epyqlib.utils.qt.Progress()
 
         if self.nvs is not None:
-            signal = self.nvs.neo.signal_by_path('CCP', 'Connect', 'CommandCounter')
+            signal = self.nvs.neo.signal_by_path("CCP", "Connect", "CommandCounter")
             self.protocol = ccp.Handler(
-                endianness='little' if signal.little_endian else 'big',
+                endianness="little" if signal.little_endian else "big",
                 tx_id=tx_id,
-                rx_id=rx_id
+                rx_id=rx_id,
             )
             from twisted.internet import reactor
+
             self.transport = epyqlib.twisted.busproxy.BusProxy(
-                protocol=self.protocol,
-                reactor=reactor,
-                bus=self.bus)
+                protocol=self.protocol, reactor=reactor, bus=self.bus
+            )
         else:
             self.protocol = None
             self.transport = None
@@ -421,9 +431,7 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         # TODO: consider using locale?  but maybe not since it's C code not
         #       raw strings
         self.sort_key = natsort.natsort_keygen(alg=natsort.ns.IGNORECASE)
-        self.role_functions[epyqlib.utils.qt.UserRoles.sort] = (
-            self.data_sort
-        )
+        self.role_functions[epyqlib.utils.qt.UserRoles.sort] = self.data_sort
 
     def data_sort(self, index):
         node = self.node_from_index(index)
@@ -431,10 +439,10 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         return self.sort_key(node.fields[index.column()])
 
     def array_truncated_message(self, maximum_children, name, length):
-        message = ('Arrays over {} elements are truncated.\n'
-                   'This has happened to `{}`[{}].'.format(
-            maximum_children, name, length
-        ))
+        message = (
+            "Arrays over {} elements are truncated.\n"
+            "This has happened to `{}`[{}].".format(maximum_children, name, length)
+        )
         epyqlib.utils.qt.dialog(
             parent=None,
             message=message,
@@ -450,9 +458,13 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
 
                 # TODO: CAMPid 9349911217316754793971391349
                 parent = node.tree_parent
-                self.changed(parent.children[0], Columns.indexes.name,
-                             parent.children[-1], Columns.indexes.name,
-                             [Qt.CheckStateRole])
+                self.changed(
+                    parent.children[0],
+                    Columns.indexes.name,
+                    parent.children[-1],
+                    Columns.indexes.name,
+                    [Qt.CheckStateRole],
+                )
 
                 return True
 
@@ -464,26 +476,25 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         self.bits_per_byte = bits_per_byte
         self.names = names
 
-        [self.git_hash] = [v for v in variables if v.name.startswith('dataLogger_gitRev_')]
-        self.git_hash = self.git_hash.name.split('0x', 1)[1]
+        [self.git_hash] = [
+            v for v in variables if v.name.startswith("dataLogger_gitRev_")
+        ]
+        self.git_hash = self.git_hash.name.split("0x", 1)[1]
         self.git_hash = int(self.git_hash, 16)
 
-        logger.debug('Updating from binary, {} variables'.format(len(variables)))
+        logger.debug("Updating from binary, {} variables".format(len(variables)))
 
         root = yield twisted.internet.threads.deferToThread(
             build_node_tree,
             variables=variables,
-            array_truncated_slot=self.array_truncated_message
+            array_truncated_slot=self.array_truncated_message,
         )
 
-        logger.debug('Creating cache')
+        logger.debug("Creating cache")
         cache = yield twisted.internet.threads.deferToThread(
-            self.create_cache,
-            only_checked=False,
-            subscribe=True,
-            root=root
+            self.create_cache, only_checked=False, subscribe=True, root=root
         )
-        logger.debug('Done creating cache')
+        logger.debug("Done creating cache")
 
         self.beginResetModel()
         self.root = root
@@ -500,24 +511,21 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         self.bits_per_byte = bits_per_byte
         self.names = names
 
-        [self.git_hash] = [v for v in variables if v.name.startswith('dataLogger_gitRev_')]
-        self.git_hash = self.git_hash.name.split('0x', 1)[1]
+        [self.git_hash] = [
+            v for v in variables if v.name.startswith("dataLogger_gitRev_")
+        ]
+        self.git_hash = self.git_hash.name.split("0x", 1)[1]
         self.git_hash = int(self.git_hash, 16)
 
-        logger.debug('Updating from binary, {} variables'.format(len(variables)))
+        logger.debug("Updating from binary, {} variables".format(len(variables)))
 
         root = build_node_tree(
-            variables=variables,
-            array_truncated_slot=self.array_truncated_message
+            variables=variables, array_truncated_slot=self.array_truncated_message
         )
 
-        logger.debug('Creating cache')
-        cache = self.create_cache(
-            only_checked=False,
-            subscribe=True,
-            root=root
-        )
-        logger.debug('Done creating cache')
+        logger.debug("Creating cache")
+        cache = self.create_cache(only_checked=False, subscribe=True, root=root)
+        logger.debug("Done creating cache")
 
         self.beginResetModel()
         self.root = root
@@ -539,16 +547,14 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
                 selected.append(node.path())
 
         self.root.traverse(
-            call_this=add_if_checked,
-            payload=selected,
-            internal_nodes=True
+            call_this=add_if_checked, payload=selected, internal_nodes=True
         )
 
-        with open(filename, 'w') as f:
-            json.dump(selected, f, indent='    ')
+        with open(filename, "w") as f:
+            json.dump(selected, f, indent="    ")
 
     def load_selection(self, filename):
-        with open(filename, 'r') as f:
+        with open(filename, "r") as f:
             selected = json.load(f)
 
         def check_if_selected(node, _):
@@ -558,19 +564,18 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
             if node.path() in selected:
                 node.set_checked(Qt.Checked)
 
-        self.root.traverse(
-            call_this=check_if_selected,
-            internal_nodes=True
-        )
+        self.root.traverse(call_this=check_if_selected, internal_nodes=True)
 
-    def create_cache(self, only_checked=True, subscribe=False,
-                     include_partially_checked=False, test=None, root=None):
+    def create_cache(
+        self,
+        only_checked=True,
+        subscribe=False,
+        include_partially_checked=False,
+        test=None,
+        root=None,
+    ):
         def default_test(node):
-            acceptable_states = {
-                Qt.Unchecked,
-                Qt.PartiallyChecked,
-                Qt.Checked
-            }
+            acceptable_states = {Qt.Unchecked, Qt.PartiallyChecked, Qt.Checked}
 
             if only_checked:
                 acceptable_states.discard(Qt.Unchecked)
@@ -597,7 +602,7 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
                 chunk = cache.new_chunk(
                     address=int(node.fields.address, 16),
                     bytes=self.zero_bytes(node.fields.size),
-                    reference=node
+                    reference=node,
                 )
                 cache.add(chunk)
 
@@ -608,26 +613,25 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
                     )
                     cache.subscribe(callback, chunk)
 
-        root.traverse(
-            call_this=update_parameter,
-            payload=cache,
-            internal_nodes=True
-        )
+        root.traverse(call_this=update_parameter, payload=cache, internal_nodes=True)
 
         return cache
 
     def zero_bytes(self, length):
-        return b'\x00' * (self.bits_per_byte // 8) * length
+        return b"\x00" * (self.bits_per_byte // 8) * length
 
     def update_chunk(self, data, node):
         node.chunk_updated(data)
 
-        self.changed(node, Columns.indexes.value,
-                     node, Columns.indexes.value,
-                     roles=[Qt.DisplayRole])
+        self.changed(
+            node,
+            Columns.indexes.value,
+            node,
+            Columns.indexes.value,
+            roles=[Qt.DisplayRole],
+        )
 
-        if isinstance(node.variable.type,
-                      epyqlib.cmemoryparser.PointerType):
+        if isinstance(node.variable.type, epyqlib.cmemoryparser.PointerType):
             # http://doc.qt.io/qt-5/qabstractitemmodel.html#layoutChanged
             # TODO: review other uses of layoutChanged and possibly 'correct' them
             self.layoutAboutToBeChanged.emit()
@@ -638,12 +642,9 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
             new_members = node.add_members(
                 base_type=epyqlib.cmemoryparser.base_type(node.variable.type),
                 address=node.address(),
-                expand_pointer=True
-            )
-            self.changePersistentIndex(
-                index,
-                self.index_from_node(node)
+                expand_pointer=True,
             )
+            self.changePersistentIndex(index, self.index_from_node(node))
             self.layoutChanged.emit()
 
             for node in new_members:
@@ -651,7 +652,7 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
                 chunk = self.cache.new_chunk(
                     address=int(node.fields.address, 16),
                     bytes=self.zero_bytes(node.fields.size),
-                    reference=node
+                    reference=node,
                 )
                 self.cache.add(chunk)
 
@@ -669,11 +670,8 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         if chunk_count == 0:
             result = QMessageBox.question(
                 parent,
-                'Clear all logging parameters?',
-                (
-                    'No variables are selected.  '
-                    'Do you want to clear all logging?'
-                ),
+                "Clear all logging parameters?",
+                ("No variables are selected.  " "Do you want to clear all logging?"),
             )
 
             if result == QMessageBox.No:
@@ -684,9 +682,12 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
             message_box = QMessageBox(parent=parent)
             message_box.setStandardButtons(QMessageBox.Ok)
 
-            text = ("Variable selection yields {chunks} memory chunks but "
-                    "is limited to {frames}.  Selection has been truncated."
-                    .format(chunks=chunk_count, frames=frame_count))
+            text = (
+                "Variable selection yields {chunks} memory chunks but "
+                "is limited to {frames}.  Selection has been truncated.".format(
+                    chunks=chunk_count, frames=frame_count
+                )
+            )
 
             epyqlib.utils.qt.dialog(
                 parent=parent,
@@ -699,14 +700,17 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         self.nv_model.start_transaction()
 
         for chunk, frame in itertools.zip_longest(
-                chunks, set_frames, fillvalue=cache.new_chunk(0, 0)):
-            print('{address}+{size}'.format(
-                address='0x{:08X}'.format(chunk._address),
-                size=len(chunk._bytes) // (self.bits_per_byte // 8)
-            ))
+            chunks, set_frames, fillvalue=cache.new_chunk(0, 0)
+        ):
+            print(
+                "{address}+{size}".format(
+                    address="0x{:08X}".format(chunk._address),
+                    size=len(chunk._bytes) // (self.bits_per_byte // 8),
+                )
+            )
 
-            address_signal = frame.signal_by_name('Address')
-            bytes_signal = frame.signal_by_name('Bytes')
+            address_signal = frame.signal_by_name("Address")
+            bytes_signal = frame.signal_by_name("Bytes")
 
             index = self.nv_model.index_from_node(address_signal)
             self.nv_model.setData(
@@ -725,13 +729,12 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         self.nv_model.submit_transaction()
 
     def record_header_length(self):
-        [x] = self.names['DataLogger_RecordHeader']
-        return (x.type.bytes
-                * (self.bits_per_byte // 8))
+        [x] = self.names["DataLogger_RecordHeader"]
+        return x.type.bytes * (self.bits_per_byte // 8)
 
     def block_header_length(self):
         try:
-            [block_header] = self.names['DataLogger_BlockHeader']
+            [block_header] = self.names["DataLogger_BlockHeader"]
         except KeyError:
             block_header_bytes = 0
         else:
@@ -743,71 +746,74 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         data_stream = io.BytesIO(data)
         raw_header = data_stream.read(self.block_header_length())
 
-        [x] = self.names['DataLogger_BlockHeader']
+        [x] = self.names["DataLogger_BlockHeader"]
         block_header_node = self.parse_block_header_into_node(
-            raw_header=raw_header,
-            bits_per_byte=self.bits_per_byte,
-            block_header_type=x
+            raw_header=raw_header, bits_per_byte=self.bits_per_byte, block_header_type=x
         )
 
         cache_and_raw_chunk = self.create_log_cache(block_header_node)
         cache = cache_and_raw_chunk.cache
         raw_chunks = cache_and_raw_chunk.raw_chunks
 
-        [x] = self.names['DataLogger_RecordHeader']
+        [x] = self.names["DataLogger_RecordHeader"]
         # TODO: hardcoded 32-bit addressing and offset assumption
         #       intended to avoid collision
-        record_header_address = 2**32 + 100
+        record_header_address = 2 ** 32 + 100
         record_header = epyqlib.cmemoryparser.Variable(
-            name='.record_header',
-            type=x,
-            address=record_header_address
+            name=".record_header", type=x, address=record_header_address
         )
         record_header_node = VariableNode(variable=record_header)
         record_header_node.add_members(
             base_type=epyqlib.cmemoryparser.base_type(record_header),
-            address=record_header.address
+            address=record_header.address,
         )
         for node in record_header_node.leaves():
             chunk = cache.new_chunk(
                 address=int(node.fields.address, 16),
                 bytes=self.zero_bytes(node.fields.size),
-                reference=node
+                reference=node,
             )
             cache.add(chunk)
 
-        raw_chunks.insert(0, cache.new_chunk(
-            address=record_header_node.variable.address,
-            bytes=self.zero_bytes(record_header_node.variable.type.bytes),
-        ))
+        raw_chunks.insert(
+            0,
+            cache.new_chunk(
+                address=record_header_node.variable.address,
+                bytes=self.zero_bytes(record_header_node.variable.type.bytes),
+            ),
+        )
 
         if self.git_hash is not None:
-            [hash_node] = [n for n in block_header_node.children
-                           if n.fields.name == 'softwareHash']
+            [hash_node] = [
+                n for n in block_header_node.children if n.fields.name == "softwareHash"
+            ]
             if self.git_hash != hash_node.fields.value:
                 if hash_node.fields.value is not None:
-                    log_hash = '{:07x}'.format(hash_node.fields.value)
+                    log_hash = "{:07x}".format(hash_node.fields.value)
                 else:
                     log_hash = str(hash_node.fields.value)
 
                 d = twisted.internet.defer.Deferred()
-                d.errback(Exception(
-                    'Git hashes from .out ({:07x}) and the log ({}) do not match'
-                    .format(self.git_hash, log_hash)
-                ))
+                d.errback(
+                    Exception(
+                        "Git hashes from .out ({:07x}) and the log ({}) do not match".format(
+                            self.git_hash, log_hash
+                        )
+                    )
+                )
                 return d
 
-        [sample_period_node] = [n for n in block_header_node.children
-                        if n.fields.name == 'samplePeriod_us']
+        [sample_period_node] = [
+            n for n in block_header_node.children if n.fields.name == "samplePeriod_us"
+        ]
         sample_period_us = sample_period_node.fields.value
 
         chunks = sorted(
             cache.contiguous_chunks(),
-            key=lambda c: (c._address != record_header_address, c)
+            key=lambda c: (c._address != record_header_address, c),
         )
 
-        variables_and_chunks = {chunk.reference: chunk
-                                for chunk in cache._chunks}
+        variables_and_chunks = {chunk.reference: chunk for chunk in cache._chunks}
 
         d = twisted.internet.threads.deferToThread(
             epyqlib.datalogger.parse_log,
@@ -824,11 +830,11 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
 
     def create_log_cache(self, block_header_node):
         chunk_ranges = []
-        chunks_node = block_header_node.get_node('chunks')
+        chunks_node = block_header_node.get_node("chunks")
         for chunk in chunks_node.children:
-            address = chunk.get_node('address')
+            address = chunk.get_node("address")
             address = address.fields.value
-            size = chunk.get_node('bytes')
+            size = chunk.get_node("bytes")
             size = size.fields.value
             chunk_ranges.append((address, size))
 
@@ -858,25 +864,25 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
 
         return CacheAndRawChunks(cache=cache, raw_chunks=raw_chunks)
 
-    def parse_block_header_into_node(self, raw_header, bits_per_byte, block_header_type):
+    def parse_block_header_into_node(
+        self, raw_header, bits_per_byte, block_header_type
+    ):
         # TODO: hardcoded 32-bit addressing and offset assumption
         #       intended to avoid collision
         block_header_cache = cmc.Cache(bits_per_byte=bits_per_byte)
         block_header = epyqlib.cmemoryparser.Variable(
-            name='.block_header',
-            type=block_header_type,
-            address=0
+            name=".block_header", type=block_header_type, address=0
         )
         block_header_node = VariableNode(variable=block_header)
         block_header_node.add_members(
             base_type=epyqlib.cmemoryparser.base_type(block_header),
-            address=block_header.address
+            address=block_header.address,
         )
         for node in block_header_node.leaves():
             chunk = block_header_cache.new_chunk(
                 address=int(node.fields.address, 16),
                 bytes=self.zero_bytes(node.fields.size),
-                reference=node
+                reference=node,
             )
             block_header_cache.add(chunk)
 
@@ -890,8 +896,7 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         return block_header_node
 
     def get_variable_nodes_by_type(self, type_name):
-        return (node for node in self.root.children
-                if node.fields.type == type_name)
+        return (node for node in self.root.children if node.fields.type == type_name)
 
     @twisted.internet.defer.inlineCallbacks
     def get_variable_value(self, *variable_path):
@@ -907,7 +912,7 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         data = yield self.protocol.upload_block(
             address_extension=ccp.AddressExtension.raw,
             address=variable.address(),
-            octets=variable.fields.size * (self.bits_per_byte // 8)
+            octets=variable.fields.size * (self.bits_per_byte // 8),
         )
         yield self.protocol.disconnect()
 
@@ -946,7 +951,7 @@ class VariableModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         data = yield self.protocol.upload_block(
             address_extension=ccp.AddressExtension.raw,
             address=variable.address(),
-            octets=variable.fields.size * (self.bits_per_byte // 8)
+            octets=variable.fields.size * (self.bits_per_byte // 8),
         )
         yield self.protocol.disconnect()
 
